@@ -80,7 +80,6 @@ typedef struct
   GstElement *effect_filter;
   GstElement *video_balance, *csp_post_balance;
   GstElement *camera_tee, *effects_tee;
-  GstElement *effects_downscaler;
   GstElement *main_valve, *effects_valve;
 
   GstCaps *preview_caps;
@@ -173,7 +172,7 @@ cheese_camera_bus_message_cb (GstBus *bus, GstMessage *message, CheeseCamera *ca
       gst_message_parse_warning (message, &err, &debug);
 
       if (err && err->message) {
-        g_warning ("%s\n", err->message);
+        g_warning ("%s: %s\n", err->message, debug);
         g_error_free (err);
       } else {
         g_warning ("Unparsable GST_MESSAGE_WARNING message.\n");
@@ -416,24 +415,14 @@ cheese_camera_create_effects_preview_bin (CheeseCamera *camera, GError **error)
   {
     cheese_camera_set_error_element_not_found (error, "effects_valve");
   }
-  priv->effects_downscaler = gst_parse_bin_from_description (
-    "videoscale ! video/x-raw-yuv,width=160,height=120 ! ffmpegcolorspace",
-    TRUE,
-    &err);
-  if (priv->effects_downscaler == NULL || err != NULL)
-  {
-    cheese_camera_set_error_element_not_found (error, "effects_downscaler");
-  }
 
   if (error != NULL && *error != NULL)
     return FALSE;
 
   gst_bin_add_many (GST_BIN (priv->effects_preview_bin),
-                    priv->effects_downscaler, priv->effects_tee,
-                    priv->effects_valve, NULL);
+		    priv->effects_valve, priv->effects_tee, NULL);
 
-  ok &= gst_element_link_many (priv->effects_valve, priv->effects_downscaler,
-                               priv->effects_tee, NULL);
+  ok &= gst_element_link_many (priv->effects_valve, priv->effects_tee, NULL);
 
   /* add ghostpads */
 
@@ -812,6 +801,7 @@ cheese_camera_force_stop_video_recording (gpointer data)
 
     cheese_camera_stop (camera);
     g_object_set (priv->camerabin, "mode", MODE_IMAGE, NULL);
+    cheese_camera_play (camera);
     priv->is_recording = FALSE;
   }
 
@@ -835,6 +825,7 @@ cheese_camera_stop_video_recording (CheeseCamera *camera)
   {
     g_signal_emit_by_name (priv->camerabin, "capture-stop", 0);
     g_object_set (priv->camerabin, "mode", MODE_IMAGE, NULL);
+    g_signal_emit (camera, camera_signals[VIDEO_SAVED], 0);
     priv->is_recording = FALSE;
   }
   else
